@@ -2,6 +2,7 @@
   This file is part of Lokalize
 
   Copyright (C) 2007-2014 by Nick Shaforostoff <shafff@ukr.net>
+                2018-2019 by Simon Depiets <sdepiets@gmail.com>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -1478,6 +1479,13 @@ static void openLxrSearch(const QString& srcFileRelPath)
                                    + QString::fromLatin1(QUrl::toPercentEncoding(srcFileRelPath))));
 }
 
+static void openLocalSource(const QString& file, int line)
+{
+    if (Settings::self()->customEditorEnabled())
+        QProcess::startDetached(QString(Settings::self()->customEditorCommand()).arg(file).arg(line));
+    else
+        QDesktopServices::openUrl(QUrl::fromLocalFile(file));
+}
 
 void EditorTab::dispatchSrcFileOpenRequest(const QString& srcFileRelPath, int line)
 {
@@ -1493,7 +1501,7 @@ void EditorTab::dispatchSrcFileOpenRequest(const QString& srcFileRelPath, int li
     relativePath.cdUp();
     QString srcAbsolutePath(relativePath.absoluteFilePath(srcFileRelPath));
     if (QFile::exists(srcAbsolutePath)) {
-        QDesktopServices::openUrl(QUrl::fromLocalFile(srcAbsolutePath));
+        openLocalSource(srcAbsolutePath, line);
         return;
     }
 
@@ -1518,7 +1526,7 @@ void EditorTab::dispatchSrcFileOpenRequest(const QString& srcFileRelPath, int li
             Project::instance()->local()->setSourceDir(dir);
     }
     if (dir.length()) {
-        auto doOpen = [srcFileRelPath]() {
+        auto doOpen = [srcFileRelPath, line]() {
             auto sourceFilePaths = Project::instance()->sourceFilePaths();
             bool found = false;
             QByteArray fn = srcFileRelPath.midRef(srcFileRelPath.lastIndexOf('/') + 1).toUtf8();
@@ -1530,7 +1538,7 @@ void EditorTab::dispatchSrcFileOpenRequest(const QString& srcFileRelPath, int li
                     continue;
                 }
                 found = true;
-                QDesktopServices::openUrl(QUrl::fromLocalFile(absFilePath));
+                openLocalSource(absFilePath, line);
                 it++;
             }
             if (!found) {
